@@ -1,7 +1,8 @@
 import pytest
+import pandas as pd
+import numpy as np
 from pandas import DataFrame, Series
 from pandas.testing import assert_frame_equal, assert_series_equal
-import numpy as np
 from qurro._df_utils import (
     ensure_df_headers_unique,
     validate_df,
@@ -178,8 +179,8 @@ def test_replace_nan():
 def get_test_data():
     """Returns test table, metadata, and ranks DataFrames.
 
-       Mostly based on/copied from get_test_data() in
-       test_filter_unextreme_features.
+    Mostly based on/copied from get_test_data() in
+    test_filter_unextreme_features.
     """
     feature_ids = ["F1", "F2", "F3", "F4", "F5", "F6", "F7", "F8"]
     table = DataFrame(
@@ -212,7 +213,7 @@ def get_test_data():
 
 def test_remove_empty_samples_and_features_samples():
     """Tests remove_empty_samples_and_features() in the simple cases of
-       removing 0, 1, and 2 empty sample(s).
+    removing 0, 1, and 2 empty sample(s).
     """
 
     # TRY REMOVING 0 SAMPLES
@@ -273,7 +274,7 @@ def test_remove_empty_samples_and_features_samples():
 
 def test_remove_empty_samples_and_features_features():
     """Tests remove_empty_samples_and_features() in the simple cases of
-       removing 1 and then 2 empty feature(s).
+    removing 1 and then 2 empty feature(s).
     """
 
     table, metadata, ranks = get_test_data()
@@ -313,7 +314,7 @@ def test_remove_empty_samples_and_features_features():
 
 def test_remove_empty_samples_and_features_both():
     """Tests remove_empty_samples_and_features() when both samples and features
-       are empty.
+    are empty.
     """
 
     table, metadata, ranks = get_test_data()
@@ -339,7 +340,7 @@ def test_remove_empty_samples_and_features_both():
         ftable, table[["Sample1", "Sample3"]].iloc[0:6], check_like=True
     )
     assert_frame_equal(
-        fmetadata, metadata.loc[set(["Sample1", "Sample3"])], check_like=True
+        fmetadata, metadata.loc[["Sample1", "Sample3"]], check_like=True
     )
     assert_frame_equal(franks, ranks.iloc[0:6])
 
@@ -662,7 +663,7 @@ def test_match_table_and_data_table_extra_feature(capsys):
         columns=table.columns,
         index=["FeatureInTableButNotRanks"],
     )
-    table = table.append(new_row, verify_integrity=True)
+    table = pd.concat([table, new_row], verify_integrity=True)
     m_table, m_metadata = match_table_and_data(table, ranks, metadata)
     # Only features in the ranks' index should be left in the table's index,
     # and the table and ranks' indices should line up.
@@ -715,7 +716,7 @@ def test_match_table_and_data_metadata_extra_sample(capsys):
         columns=metadata.columns,
         index=["SampleInMDButNotTable"],
     )
-    metadata = metadata.append(new_row, verify_integrity=True)
+    metadata = pd.concat([metadata, new_row], verify_integrity=True)
     m_table, m_metadata = match_table_and_data(table, ranks, metadata)
     assert len(set(m_table.columns) & set(m_metadata.index)) == len(
         table.columns
@@ -740,7 +741,7 @@ def test_match_table_and_data_ranked_features_not_in_table():
     # (...because that is not a good situation.)
     table, metadata, ranks = get_test_data()
     new_feature_row = DataFrame([[9, 0]], columns=ranks.columns, index=["F9"])
-    ranks_modified = ranks.append(new_feature_row, verify_integrity=True)
+    ranks_modified = pd.concat([ranks, new_feature_row], verify_integrity=True)
     with pytest.raises(ValueError) as exception_info:
         match_table_and_data(table, ranks_modified, metadata)
     expected_message = (
@@ -754,8 +755,8 @@ def test_match_table_and_data_ranked_features_not_in_table():
     new_feature_row = DataFrame(
         [[10, -1]], columns=ranks.columns, index=["F10"]
     )
-    ranks_modified = ranks_modified.append(
-        new_feature_row, verify_integrity=True
+    ranks_modified = pd.concat(
+        [ranks_modified, new_feature_row], verify_integrity=True
     )
     with pytest.raises(ValueError) as exception_info:
         match_table_and_data(table, ranks_modified, metadata)
@@ -789,7 +790,7 @@ def test_match_table_and_data_complex(capsys):
 
     # Add the extra feature to the table
     new_f_row = DataFrame([[1, 2, 3, 4]], columns=table.columns, index=["F9"])
-    table = table.append(new_f_row, verify_integrity=True)
+    table = pd.concat([table, new_f_row], verify_integrity=True)
 
     # Add the extra sample to the table
     table["Sample5"] = 5
@@ -798,7 +799,7 @@ def test_match_table_and_data_complex(capsys):
     new_s_row = DataFrame(
         [[4, 3, 2, 1]], columns=metadata.columns, index=["SampleM"]
     )
-    metadata = metadata.append(new_s_row, verify_integrity=True)
+    metadata = pd.concat([metadata, new_s_row], verify_integrity=True)
 
     # Ok, actually run the function!
     m_table, m_metadata = match_table_and_data(table, ranks, metadata)
@@ -824,8 +825,8 @@ def test_match_table_and_data_complex(capsys):
 
 def verify_spc_data_integrity(output_feature_data, initial_feature_data):
     """Checks that add_sample_presence_count() doesn't change any of the
-       initially input feature_data -- it just adds a qurro_spc column, and
-       doesn't change the DF in any other way.
+    initially input feature_data -- it just adds a qurro_spc column, and
+    doesn't change the DF in any other way.
     """
     ifd_in_ofd = output_feature_data.drop("qurro_spc", axis="columns")
     assert_frame_equal(ifd_in_ofd, initial_feature_data)
@@ -885,10 +886,10 @@ def test_add_sample_presence_count_zeros():
 
 def test_add_sample_presence_count_name_error():
     """Checks the case where the feature data already contains a column
-       called qurro_spc.
+    called qurro_spc.
 
-       This should never happen due to check_column_names() being called, but
-       we might as well be careful.
+    This should never happen due to check_column_names() being called, but
+    we might as well be careful.
     """
     table, metadata, ranks = get_test_data()
     ranks.columns = ["Rank 0", "qurro_spc"]
@@ -898,7 +899,7 @@ def test_add_sample_presence_count_name_error():
 
 def test_vibe_check_safe_range_invalid_safe_ranges():
     """Checks cases where the input range specified to vibe_check() is somehow
-       invalid.
+    invalid.
     """
     table, metadata, ranks = get_test_data()
 
@@ -949,8 +950,8 @@ def test_vibe_check_failures():
     ) in str(exception_info.value)
 
     # Test failure, with the default safe range, on a few small cases.
-    lower_lim = -(2 ** 53) - 1
-    upper_lim = (2 ** 53) - 1
+    lower_lim = -(2**53) - 1
+    upper_lim = (2**53) - 1
 
     weird_small_values = [lower_lim - 1, lower_lim * 2, lower_lim * 3]
     for w in weird_small_values:
